==================
zfit introduction
==================

Following and introduction to the elements of zfit

.. toctree::
    :titlesonly:
    :maxdepth: 1

    intro/space
    intro/parameter
    intro/model
    intro/data
    intro/loss
    intro/minimize
